==> open-parties-and-claims-fabric-1.20.1-0.25.8-sources.jar: xaero/pac/common/mixin/MixinPlayer.java <==
/*
 * Open Parties and Claims - adds chunk claims and player parties to Minecraft
 * Copyright (C) 2022-2025, Xaero <xaero1996@gmail.com> and contributors
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of version 3 of the GNU Lesser General Public License
 * (LGPL-3.0-only) as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received copies of the GNU Lesser General Public License
 * and the GNU General Public License along with this program.
 * If not, see <https://www.gnu.org/licenses/>.
 */

package xaero.pac.common.mixin;

import net.minecraft.core.BlockPos;
import net.minecraft.core.Direction;
import net.minecraft.world.entity.player.Player;
import net.minecraft.world.item.ItemStack;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;
import xaero.pac.common.server.core.ServerCore;

@Mixin(Player.class)
public class MixinPlayer {

	@Inject(at = @At("HEAD"), method = "mayUseItemAt", cancellable = true)
	public void onMayUseItemAt(BlockPos blockPos, Direction direction, ItemStack itemStack, CallbackInfoReturnable<Boolean> info){
		if(!ServerCore.mayUseItemAt((Player)(Object)this, blockPos, direction, itemStack))
			info.setReturnValue(false);
	}

}

==> open-parties-and-claims-fabric-1.21.11-0.25.10-sources.jar: xaero/pac/common/mixin/MixinPlayer.java <==
/*
 * Open Parties and Claims - adds chunk claims and player parties to Minecraft
 * Copyright (C) 2022-2026, Xaero <xaero1996@gmail.com> and contributors
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of version 3 of the GNU Lesser General Public License
 * (LGPL-3.0-only) as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received copies of the GNU Lesser General Public License
 * and the GNU General Public License along with this program.
 * If not, see <https://www.gnu.org/licenses/>.
 */

package xaero.pac.common.mixin;

import net.minecraft.core.BlockPos;
import net.minecraft.core.Direction;
import net.minecraft.world.entity.Entity;
import net.minecraft.world.entity.EquipmentSlot;
import net.minecraft.world.entity.LivingEntity;
import net.minecraft.world.entity.player.Player;
import net.minecraft.world.item.ItemStack;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;
import xaero.pac.common.server.core.ServerCore;

@Mixin(Player.class)
public class MixinPlayer {

	@Inject(at = @At("HEAD"), method = "mayUseItemAt", cancellable = true)
	public void onMayUseItemAt(BlockPos blockPos, Direction direction, ItemStack itemStack, CallbackInfoReturnable<Boolean> info){
		if(!ServerCore.mayUseItemAt((Player)(Object)this, blockPos, direction, itemStack))
			info.setReturnValue(false);
	}

	@Inject(at = @At("HEAD"), method = "stabAttack", cancellable = true)
	public void onStabAttack(
			EquipmentSlot slot, Entity targetEntity,
			float baseDamage, boolean hurt,
			boolean knockback, boolean dismount,
			CallbackInfoReturnable<Boolean> info
	) {
		if(ServerCore.onStabAttack((LivingEntity) (Object)this, targetEntity, slot))
			info.setReturnValue(false);
	}

}
